@@ -26,9 +26,12 @@
 #include "sbkpython.h"
 #include <list>
 #include <map>
+#include <set>
+#include <string>
 
 struct SbkObject;
 struct SbkObjectType;
+struct SbkConverter;
 
 namespace Shiboken
 {
@@ -89,6 +92,7 @@ struct SbkObjectPrivate
     }
 };
 
+// TODO-CONVERTERS: to be deprecated/removed
 /// The type behaviour was not defined yet
 #define BEHAVIOUR_UNDEFINED 0
 /// The type is a value type
@@ -98,16 +102,13 @@ struct SbkObjectPrivate
 
 struct SbkObjectTypePrivate
 {
+    SbkConverter* converter;
     int* mi_offsets;
     MultipleInheritanceInitFunction mi_init;
 
     /// Special cast function, null if this class doesn't have multiple inheritance.
     SpecialCastFunction mi_specialcast;
     TypeDiscoveryFuncV2 type_discovery;
-    /// Extended "isConvertible" function to be used when a conversion operator is defined in another module.
-    ExtendedIsConvertibleFunc ext_isconvertible;
-    /// Extended "toCpp" function to be used when a conversion operator is defined in another module.
-    ExtendedToCppFunc ext_tocpp;
     /// Pointer to a function responsible for deletion of the C++ instance calling the proper destructor.
     ObjectDestructor cpp_dtor;
     /// True if this type holds two or more C++ instances, e.g.: a Python class which inherits from two C++ classes.
@@ -115,6 +116,7 @@ struct SbkObjectTypePrivate
     /// True if this type was defined by the user.
     int is_user_type : 1;
     /// Tells is the type is a value type or an object-type, see BEHAVIOUR_* constants.
+    // TODO-CONVERTERS: to be deprecated/removed
     int type_behaviour : 2;
     /// C++ name
     char* original_name;
@@ -197,17 +199,26 @@ private:
     PyTypeObject* m_desiredType;
 };
 
+/// Call the destructor of each C++ object held by a Python object
 class DtorCallerVisitor : public HierarchyVisitor
 {
 public:
     DtorCallerVisitor(SbkObject* pyObj) : m_pyObj(pyObj) {}
     void visit(SbkObjectType* node);
     void done();
-private:
+protected:
     std::list<std::pair<void*, SbkObjectType*> > m_ptrs;
     SbkObject* m_pyObj;
 };
 
+/// Dealloc of each C++ object held by a Python object, this implies a call to the C++ object destructor
+class DeallocVisitor : public DtorCallerVisitor
+{
+public:
+    DeallocVisitor(SbkObject* pyObj) : DtorCallerVisitor(pyObj) {}
+    void done();
+};
+
 /// \internal Internal function used to walk on classes inheritance trees.
 /**
 *   Walk on class hierarchy using a DFS algorithm.
