@@ -31,6 +31,7 @@ extern "C"
 
 extern LIBSHIBOKEN_API PyTypeObject SbkEnumType_Type;
 struct SbkObjectType;
+struct SbkConverter;
 
 } // extern "C"
 
@@ -88,9 +89,13 @@ namespace Enum
 
     LIBSHIBOKEN_API long getValue(PyObject* enumItem);
     LIBSHIBOKEN_API PyObject* getEnumItemFromValue(PyTypeObject* enumType, long itemValue);
+
+    /// Sets the enum's type converter.
+    LIBSHIBOKEN_API void setTypeConverter(PyTypeObject* enumType, SbkConverter* converter);
+    /// Returns the converter assigned to the enum \p type.
+    LIBSHIBOKEN_API SbkConverter* getTypeConverter(PyTypeObject* enumType);
 }
 
 } // namespace Shiboken
 
 #endif // SKB_PYENUM_H
-
